# 表格组件 v-table-column
> v0.7

## 概述
使用了https://xuliangzhan_admin.gitee.io/vxe-table/v2/ 进行重新封装，
默认开始大数据优化处理，不开启时使用和element-ui一样

封装了结合 iView 和 element-ui 风格使用的el-table，渲染数据方式可参照element-ui，亦可参照iView，属性和事件和el-table基本相同。
该组件与 element-ui 的 el-table 的最大区别是修改部分属性默认值，以及自动计算表格高度、列宽、固定首尾列、更智能的树形表格等功能。
下面，将在说明中详细介绍这些功能

### 特点
- 设置属性默认值 stripe，是否显示斑马纹。该属性默认值为`true`，如果该表格为树形表格（这里指一定要有下级的树形表格，以下都称之为 “树形表格” ），则默认值为 `false`
- 设置属性默认值 defaultExpandAll  当表格为树形表格时，默认值为 true，默认展开所有节点，且表头会带有 “展开全部” 和 “收起全部” 的功能
- 设置属性默认值 height  默认高度自动计算，但当表格不搭配分页组件使用时，请设置 :noPage="true" 的属性
- 针对树形表格进行优化，默认全部收起，且在表头处提供了一键展开和收起所有列表数据的功能，方便快捷
- 自动计算部分列宽，详细说明见 ../v-table-column/README.md
- 自动固定首尾列，详细说明见 ../v-table-column/README.md

## 基本使用

### 普通表格

```
<v-table :data="colData">
	<v-table-column :label="label" prop="prop"></v-table-column>
</v-table>

或

<v-table :data="colData" :columns="columns"></v-table>

data: {
	colData: [],
	columns: [
		{
			title: "部门名称",
			key: "ORG_NAME",
			align: "center"
		},
		{
			title: "部门描述",
			key: "NOTE",
			align: "center"
		},
		{
			title: "成员数量",
			key: "num",
			align: "center",
			width: 66,
			render: (h, params) => {
				return tableOperRender(h, "", [params.row.num], () => {
					//点击部门成员数量
					this.$router.push("/personnel-manage/person-manager?orgCode=" + params.row.ORG_CODE);
				});
			}
		},
		{
			title: "上级部门",
			key: "PARENT_NAME",
			align: "center"
		},
		{
			title: "操作",
			render: (h, params) => {
				return tableOperRender(h, "", () => {
					//修改
					this.showModalFn(params.row);
				}, () => {
					//删除
					this.deleteItem(params.row.ORG_CODE);
				});
			},
			align: "center",
			width: 150
		}
	],
}

```

### 树形表格
1、需要配置row-key，tree-props，tree-node（改列有展开图片按钮）
2、顶部的展开全部需要手动配置，:columns="columns"
3、自定义的展开收起全部可以用，triggerExpand(flag)方法

```
<v-table ref="table" v-loading="tableLoading" class="menu-table" row-key="MENU_CODE" :columns="columns" :data="data" :tree-props="{children: 'children', hasChildren: 'hasChildren'}">
	<v-table-column tree-node prop="name" label="名称" width="68" align="center"></v-table-column>
	<v-table-column label="操作">
		<template slot-scope="scope">
			<v-button v-perm="'MenuEdit'" @click.native.prevent="handleEditClick(scope.row.MENU_CODE)">修改</v-button>
			<v-button v-perm="'MenuEdit'" @click.native.prevent="handleDelClick(scope.row, data)">删除</v-button>
		</template>
	</v-table-column>
</v-table>

<script>
columns: [
	{
		label: "功能项",
		prop: "name",
		width: 300,
		expand: true,
		treeNode: true
	}
]
</script>
```

## api

### props
| 属性          | 说明                                  | 类型     | 默认值  |
| ------------ | ------------------------------------- | ------- | ------ |
| columns      | 列表配置                               | Array    | []     |
| highlight-current-row | 是否使用单选高亮                        |  Boolean | false  |
| loading      | 加载提示                               | Boolean  | false  |
| tableName    | 设置内部 el-table 的 ref,用来调用方法    |  String  |'vTable' |
| noPage       | 当前表格是否不搭配分页组件使用，该属性会影响到表格的默认高度    |  Boolean  | false |
| height       | 表格的高度（若不想固定高度，请设置height="unset"）|  Number  |         |
| maxHeight    | 表格的最大高度（注意：父元素可能会出现滚动条）|  Number, String  |         |
| border       | 显示表格边框                           |  Boolean  |  true  |

### events

### methods

- triggerExpand(flag)，flag为true时收起所有，false展开所有

### tips
- 在选中高亮（highlight-current-row）表格里，如果想在操作列点击按钮的时候，不触发选中高亮事件，可在按钮的点击事件使用阻止冒泡的方法：
  1. 绑定点击事件写成 `<v-button @click.native.stop="onClick($event)"></v-button>`;
  2. 或者在 onClick 事件里加上 `$event.stopPropagation()`。


---
